package com.ruoyi.rocketmq.service;

import com.ruoyi.rocketmq.domain.InitialBandwidthTraffic;
import com.ruoyi.rocketmq.domain.InitialBandwidthTrafficTemp;

import java.util.List;

/**
 * 初始带宽流量临时表Service接口
 * 
 * @author gyt
 * @date 2025-11-05
 */
public interface IInitialBandwidthTrafficTempService 
{
    /**
     * 查询初始带宽流量临时表
     * 
     * @param id 初始带宽流量临时表主键
     * @return 初始带宽流量临时表
     */
    public InitialBandwidthTrafficTemp selectInitialBandwidthTrafficTempById(Long id);

    /**
     * 查询初始带宽流量临时表列表
     * 
     * @param initialBandwidthTrafficTemp 初始带宽流量临时表
     * @return 初始带宽流量临时表集合
     */
    public List<InitialBandwidthTrafficTemp> selectInitialBandwidthTrafficTempList(InitialBandwidthTrafficTemp initialBandwidthTrafficTemp);

    /**
     * 新增初始带宽流量临时表
     * 
     * @param initialBandwidthTrafficTemp 初始带宽流量临时表
     * @return 结果
     */
    public int insertInitialBandwidthTrafficTemp(InitialBandwidthTrafficTemp initialBandwidthTrafficTemp);

    /**
     * 修改初始带宽流量临时表
     * 
     * @param initialBandwidthTrafficTemp 初始带宽流量临时表
     * @return 结果
     */
    public int updateInitialBandwidthTrafficTemp(InitialBandwidthTrafficTemp initialBandwidthTrafficTemp);

    /**
     * 批量删除初始带宽流量临时表
     * 
     * @param ids 需要删除的初始带宽流量临时表主键集合
     * @return 结果
     */
    public int deleteInitialBandwidthTrafficTempByIds(Long[] ids);

    /**
     * 删除初始带宽流量临时表信息
     * 
     * @param id 初始带宽流量临时表主键
     * @return 结果
     */
    public int deleteInitialBandwidthTrafficTempById(Long id);

    /**
     * 根据clientId删除信息
     * @param clientId
     * @return
     */
    int deleteTempMsgByClientId(String clientId);

    /**
     * 批量新增临时表信息
     * @param interfaces
     * @return
     */
    int batchInsertServerTemp(List<InitialBandwidthTraffic> interfaces);
}
