package com.ruoyi.rocketmq.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import com.ruoyi.rocketmq.domain.InitialBandwidthTrafficTemp;
import com.ruoyi.rocketmq.service.IInitialBandwidthTrafficTempService;
import com.ruoyi.common.core.web.controller.BaseController;
import com.ruoyi.common.core.web.domain.AjaxResult;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.ruoyi.common.core.web.page.TableDataInfo;

/**
 * 初始带宽流量临时表Controller
 * 
 * @author gyt
 * @date 2025-11-05
 */
@RestController
@RequestMapping("/trafficTemp")
public class InitialBandwidthTrafficTempController extends BaseController
{
    @Autowired
    private IInitialBandwidthTrafficTempService initialBandwidthTrafficTempService;

    /**
     * 查询初始带宽流量临时表列表
     */
    @RequiresPermissions("rocketmq:trafficTemp:list")
    @GetMapping("/list")
    public TableDataInfo list(InitialBandwidthTrafficTemp initialBandwidthTrafficTemp)
    {
        startPage();
        List<InitialBandwidthTrafficTemp> list = initialBandwidthTrafficTempService.selectInitialBandwidthTrafficTempList(initialBandwidthTrafficTemp);
        return getDataTable(list);
    }

    /**
     * 导出初始带宽流量临时表列表
     */
    @RequiresPermissions("rocketmq:trafficTemp:export")
    @Log(title = "初始带宽流量临时表", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, InitialBandwidthTrafficTemp initialBandwidthTrafficTemp)
    {
        List<InitialBandwidthTrafficTemp> list = initialBandwidthTrafficTempService.selectInitialBandwidthTrafficTempList(initialBandwidthTrafficTemp);
        ExcelUtil<InitialBandwidthTrafficTemp> util = new ExcelUtil<InitialBandwidthTrafficTemp>(InitialBandwidthTrafficTemp.class);
        util.exportExcel(response, list, "初始带宽流量临时表数据");
    }

    /**
     * 获取初始带宽流量临时表详细信息
     */
    @RequiresPermissions("rocketmq:trafficTemp:query")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(initialBandwidthTrafficTempService.selectInitialBandwidthTrafficTempById(id));
    }

    /**
     * 新增初始带宽流量临时表
     */
    @RequiresPermissions("rocketmq:trafficTemp:add")
    @Log(title = "初始带宽流量临时表", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody InitialBandwidthTrafficTemp initialBandwidthTrafficTemp)
    {
        return toAjax(initialBandwidthTrafficTempService.insertInitialBandwidthTrafficTemp(initialBandwidthTrafficTemp));
    }

    /**
     * 修改初始带宽流量临时表
     */
    @RequiresPermissions("rocketmq:trafficTemp:edit")
    @Log(title = "初始带宽流量临时表", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody InitialBandwidthTrafficTemp initialBandwidthTrafficTemp)
    {
        return toAjax(initialBandwidthTrafficTempService.updateInitialBandwidthTrafficTemp(initialBandwidthTrafficTemp));
    }

    /**
     * 删除初始带宽流量临时表
     */
    @RequiresPermissions("rocketmq:trafficTemp:remove")
    @Log(title = "初始带宽流量临时表", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(initialBandwidthTrafficTempService.deleteInitialBandwidthTrafficTempByIds(ids));
    }
}
